@@ -1,8 +1,11 @@
 """
 Factory class for creating Overloaded GSI Payloads
 """
+import warnings
 from typing import Any, List, Tuple, Optional
 
+from deprecation import deprecated
+
 from ckf_api_toolkit.aws_dynamo.condition_expression import DynamoConditionExpressionFactory, \
     DynamoConditionExpressionComparisonComparator
 from ckf_api_toolkit.aws_dynamo.constants import DynamoReturnValues
@@ -194,8 +197,31 @@ class OverloadedGsiPayloadFactory:
         """
         return self.sk_name if not gsi else self._get_gsi_sk_name(gsi)
 
+    def get_query_payload(self, primary_key_value: Any, sort_key_value: Optional[Any] = None, *,
+                          gsi: Optional[int] = None):
+        """Returns a payload for a generic query operation using a primary key and an optional sort key
+
+        Args:
+            primary_key_value (Any): The PK to use for this query payload
+            sort_key_value (Optional[Any]): The SK to use for this query payload
+            gsi (Optional[int]): GSI number for the query
+
+        Returns:
+            (DynamoQueryPayload) A payload for a query
+        """
+        payload = self._get_possible_gsi_payload(gsi)
+        primary_key_name = self._get_possible_gsi_pk_name(gsi)
+        payload.add_partition_key_eq_condition_expression(primary_key_name, primary_key_value)
+
+        if sort_key_value:
+            sk_condition = DynamoQueryKeyCondition(self._get_possible_gsi_sk_name(gsi))
+            sk_condition.add_key_equals(sort_key_value)
+
+        return payload
+
+    @deprecated(details="Use get_query_payload function instead.", deprecated_in="0.6.2")
     def get_explicit_pk_query_payload(self, primary_key_value: Any, *, gsi: Optional[int] = None) -> DynamoQueryPayload:
-        """Returns a payload for a query operation with an explicit PK
+        """Returns a payload for a query operation with an explicit PK - DEPRECATED, use get_query_payload
 
         Args:
             primary_key_value (Any): The PK to use for this query payload
@@ -204,6 +230,7 @@ class OverloadedGsiPayloadFactory:
         Returns:
             (DynamoQueryPayload) A payload for a query with an explicit PK
         """
+
         payload = self._get_possible_gsi_payload(gsi)
         primary_key_name = self._get_possible_gsi_pk_name(gsi)
         payload.add_partition_key_eq_condition_expression(primary_key_name, primary_key_value)
